( cd usr/lib ; rm -rf libsamplerate.so.0 )
( cd usr/lib ; ln -sf libsamplerate.so.0.1.1 libsamplerate.so.0 )
( cd usr/lib ; rm -rf libsamplerate.so )
( cd usr/lib ; ln -sf libsamplerate.so.0.1.1 libsamplerate.so )
